@@ -130,7 +130,7 @@ def filterQuotesByBook(db, book, min_likes=0):
                 by_book.append(quote[0])
     return by_book
 
-def export(quotes, saveFile, enc=2):
+def export(quotes, saveFile, enc):
 	from grtoolkit.Storage import File
 	save = File(saveFile, enc=enc)
 
